"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.last = void 0;
const shared_1 = require("../../shared");
/**
 * Returns the last element of a sequence.
 * If predicate is specified, the last element of a sequence that satisfies a specified condition.
 * @param source An AsyncIterable<T> to return the last element of.
 * @param predicate A function to test each element for a condition. Optional.
 * @throws {InvalidOperationException} The source sequence is empty.
 * @returns The value at the last position in the source sequence
 * or the last element in the sequence that passes the test in the specified predicate function.
 */
async function last(source, predicate) {
    if (predicate) {
        return last2(source, predicate);
    }
    else {
        return last1(source);
    }
}
exports.last = last;
const last1 = async (source) => {
    let lastItem = null;
    for await (const value of source) {
        lastItem = value;
    }
    if (!lastItem) {
        throw new shared_1.InvalidOperationException(shared_1.ErrorString.NoElements);
    }
    return lastItem;
};
const last2 = async (source, predicate) => {
    let lastItem = null;
    for await (const value of source) {
        if (predicate(value) === true) {
            lastItem = value;
        }
    }
    if (!lastItem) {
        throw new shared_1.InvalidOperationException(shared_1.ErrorString.NoMatch);
    }
    return lastItem;
};
