"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.lastOrDefaultAsync = void 0;
/**
 * Returns the last element of a sequence that satisfies a specified condition.
 * @param source An AsyncIterable<T> to return the last element of.
 * @param predicate A function to test each element for a condition.
 * @returns The last element in the sequence that passes the test in the specified predicate function.
 * Null if no elements.
 */
async function lastOrDefaultAsync(source, predicate) {
    let last = null;
    for await (const value of source) {
        if (await predicate(value) === true) {
            last = value;
        }
    }
    return last;
}
exports.lastOrDefaultAsync = lastOrDefaultAsync;
