"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bindString = void 0;
const shared_1 = require("../shared");
const BasicEnumerable_1 = require("../sync/BasicEnumerable");
/**
 * Adds LINQ methods to String prototype
 */
exports.bindString = () => {
    const prototype = String.prototype;
    const propertyNames = Object.getOwnPropertyNames(BasicEnumerable_1.BasicEnumerable.prototype)
        // eslint-disable-next-line @typescript-eslint/array-type
        .filter((v) => v !== "constructor");
    for (const prop of propertyNames) {
        // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
        prototype[prop] = prototype[prop] || BasicEnumerable_1.BasicEnumerable.prototype[prop];
    }
    prototype.first = function (predicate) {
        if (predicate) {
            for (let i = 0; i < this.length; i++) {
                const value = this[i];
                if (predicate(value) === true) {
                    return value;
                }
            }
            throw new shared_1.InvalidOperationException(shared_1.ErrorString.NoMatch);
        }
        if (this.length === 0) {
            throw new shared_1.InvalidOperationException(shared_1.ErrorString.NoElements);
        }
        return this[0];
    };
    prototype.firstOrDefault = function (predicate) {
        if (predicate) {
            for (let i = 0; i < this.length; i++) {
                const value = this[i];
                if (predicate(value) === true) {
                    return value;
                }
            }
            return null;
        }
        return this.length === 0 ? null : this[0];
    };
    prototype.count = function (predicate) {
        if (predicate) {
            // eslint-disable-next-line no-shadow
            let count = 0;
            for (let i = 0; i < this.length; i++) {
                if (predicate(this[i]) === true) {
                    count++;
                }
            }
            return count;
        }
        else {
            return this.length;
        }
    };
    prototype.elementAt = function (index) {
        if (index < 0 || index >= this.length) {
            throw new shared_1.ArgumentOutOfRangeException("index");
        }
        return this[index];
    };
    prototype.elementAtOrDefault = function (index) {
        return this[index] || null;
    };
    prototype.last = function (predicate) {
        if (predicate) {
            for (let i = this.length - 1; i >= 0; i--) {
                const value = this[i];
                if (predicate(value) === true) {
                    return value;
                }
            }
            throw new shared_1.InvalidOperationException(shared_1.ErrorString.NoMatch);
        }
        else {
            if (this.length === 0) {
                throw new shared_1.InvalidOperationException(shared_1.ErrorString.NoElements);
            }
            return this[this.length - 1];
        }
    };
    prototype.lastOrDefault = function (predicate) {
        if (predicate) {
            for (let i = this.length - 1; i >= 0; i--) {
                const value = this[i];
                if (predicate(value) === true) {
                    return value;
                }
            }
            return null;
        }
        else {
            return this.length === 0 ? null : this[this.length - 1];
        }
    };
    prototype.reverse = function () {
        // eslint-disable-next-line @typescript-eslint/no-this-alias
        const outer = this;
        function* generator() {
            for (let i = outer.length - 1; i >= 0; i--) {
                yield outer[i];
            }
        }
        return new BasicEnumerable_1.BasicEnumerable(generator);
    };
};
