"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.asAsyncKeyMap = void 0;
/**
 * Converts values to a key values map.
 * @param source Async Iterable
 * @param keySelector Async Key Selector for Map
 * @returns Promise for a Map for Key to Values
 */
exports.asAsyncKeyMap = async (source, keySelector) => {
    const map = new Map();
    for await (const item of source) {
        const key = await keySelector(item);
        const currentMapping = map.get(key);
        if (currentMapping) {
            currentMapping.push(item);
        }
        else {
            map.set(key, [item]);
        }
    }
    return map;
};
