"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.allAsync = void 0;
const _nextIterationAsync_1 = require("./_nextIterationAsync");
/**
 * Determines whether all elements of a sequence satisfy a condition.
 * @param source An IParallelEnumerable<T> that contains the elements to apply the predicate to.
 * @param predicate A function to test each element for a condition.
 * @returns ``true`` if every element of the source sequence passes the test in the specified predicate,
 * or if the sequence is empty; otherwise, ``false``.
 */
function allAsync(source, predicate) {
    const nextIter = _nextIterationAsync_1.nextIterationAsync(source, async (x) => {
        if (await predicate(x) === false) {
            throw new Error(String(false));
        }
        return true;
    });
    switch (nextIter.type) {
        case 0 /* PromiseToArray */:
            return nextIter
                .generator()
                .then(() => true, () => false);
        case 1 /* ArrayOfPromises */:
            return Promise.all(nextIter.generator())
                .then(() => true, () => false);
        case 2 /* PromiseOfPromises */:
            return nextIter.generator()
                .then(Promise.all.bind(Promise))
                .then(() => true, () => false);
    }
}
exports.allAsync = allAsync;
