"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.concatenate = void 0;
const BasicParallelEnumerable_1 = require("../BasicParallelEnumerable");
/**
 * Concatenates two sequences.
 * @param first The first sequence to concatenate.
 * @param second The sequence to concatenate to the first sequence.
 * @returns An IParallelEnumerable<T> that contains the concatenated elements of the two input sequences.
 */
function concatenate(
// eslint-disable-next-line no-shadow
first, second) {
    const generator = async () => {
        // Wait for both enumerables
        const promiseResults = await Promise.all([first.toArray(), second.toArray()]);
        // Concat
        const firstData = promiseResults[0];
        const secondData = promiseResults[1];
        const data = new Array(firstData.length + secondData.length);
        let i = 0;
        for (; i < firstData.length; i++) {
            data[i] = firstData[i];
        }
        for (let j = 0; j < secondData.length; j++, i++) {
            data[i] = secondData[j];
        }
        return data;
    };
    return new BasicParallelEnumerable_1.BasicParallelEnumerable({
        generator,
        type: 0 /* PromiseToArray */,
    });
}
exports.concatenate = concatenate;
