"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.elementAt = void 0;
const shared_1 = require("../../shared");
/**
 * Returns the element at a specified index in a sequence.
 * @param source An IEnumerable<T> to return an element from.
 * @param index The zero-based index of the element to retrieve.
 * @throws {ArgumentOutOfRangeException}
 * index is less than 0 or greater than or equal to the number of elements in source.
 * @returns The element at the specified index in the sequence.
 */
async function elementAt(source, index) {
    if (index < 0) {
        throw new shared_1.ArgumentOutOfRangeException("index");
    }
    const dataFunc = source.dataFunc;
    switch (dataFunc.type) {
        case 0 /* PromiseToArray */:
            return dataFunc.generator().then((values) => {
                if (index >= values.length) {
                    throw new shared_1.ArgumentOutOfRangeException("index");
                }
                else {
                    return values[index];
                }
            });
        case 1 /* ArrayOfPromises */:
            return Promise.all(dataFunc.generator()).then((values) => {
                if (index >= values.length) {
                    throw new shared_1.ArgumentOutOfRangeException("index");
                }
                else {
                    return values[index];
                }
            });
        case 2 /* PromiseOfPromises */:
            return dataFunc.generator().then(async (values) => {
                if (index >= values.length) {
                    throw new shared_1.ArgumentOutOfRangeException("index");
                }
                else {
                    return await values[index];
                }
            });
    }
}
exports.elementAt = elementAt;
