"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.firstOrDefaultAsync = void 0;
const toArray_1 = require("./toArray");
/**
 * Returns first element in sequence that satisfies. Returns null if no value found.
 * @param source An IParallelEnumerable<T> to return an element from.
 * @param predicate An async function to test each element for a condition.
 * @returns The first element that passes the test in the specified predicate function.
 * Returns null if no value found.
 */
async function firstOrDefaultAsync(source, predicate) {
    const data = await toArray_1.toArray(source);
    for (const value of data) {
        if (await predicate(value) === true) {
            return value;
        }
    }
    return null;
}
exports.firstOrDefaultAsync = firstOrDefaultAsync;
