"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.maxAsync = void 0;
const shared_1 = require("../../shared");
const BasicParallelEnumerable_1 = require("../BasicParallelEnumerable");
const _nextIterationAsync_1 = require("./_nextIterationAsync");
/**
 * Invokes an async transform function on each element of a sequence and returns the maximum value.
 * @param source A sequence of values to determine the maximum value of.
 * @param selector A transform function to apply to each element.
 * @throws {InvalidOperationException} source contains no elements.
 * @returns The maximum value in the sequence.
 */
async function maxAsync(source, selector) {
    const dataFunc = _nextIterationAsync_1.nextIterationAsync(source, selector);
    const maxInfo = await new BasicParallelEnumerable_1.BasicParallelEnumerable(dataFunc).toArray();
    if (maxInfo.length === 0) {
        throw new shared_1.InvalidOperationException(shared_1.ErrorString.NoElements);
    }
    return Math.max.apply(null, maxInfo);
}
exports.maxAsync = maxAsync;
